package cn.com.qmth.mps.service.impl;

import java.util.HashMap;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.qmth.boot.core.exception.StatusException;
import com.qmth.boot.tools.uuid.FastUUID;

import cn.com.qmth.mps.bean.User;
import cn.com.qmth.mps.config.SysProperty;
import cn.com.qmth.mps.entity.UserEntity;
import cn.com.qmth.mps.enums.Role;
import cn.com.qmth.mps.service.AuthService;
import cn.com.qmth.mps.service.UserService;
import cn.com.qmth.mps.util.ActiveDataUtil;
import cn.com.qmth.mps.util.HttpUtil;
import cn.com.qmth.mps.vo.AdminLoginVo;
import net.sf.json.JSONObject;

@Service
public class AuthServiceImpl implements AuthService {
	private static String uri="https://api.weixin.qq.com/sns/jscode2session";
	@Autowired
	private UserService userService;
	@Autowired
	private SysProperty sysProperty;
	@Override
	public AdminLoginVo loginWxApp(String wxappCode, String phone) {
		
		Map<String,String> params=new HashMap<>();
		params.put("appid", sysProperty.getWxappAppid());
		params.put("secret", sysProperty.getWxappSecret());
		params.put("js_code", wxappCode);
		params.put("grant_type", "authorization_code");
		String ret;
		try {
			ret=HttpUtil.httpActionGet(uri, null, params);
		} catch (Exception e) {
			throw new StatusException("登录失败",e);
		}
		JSONObject jo=JSONObject.fromObject(ret);
		if(jo.containsKey("errmsg")) {
			throw new StatusException("登录失败,"+jo.getString("errmsg"));
		}
		UserEntity userE=userService.getByLoginName(phone);
		if(userE==null) {
			throw new StatusException("该手机号不存在");
		}
		if(!userE.getEnable()) {
			throw new StatusException("该用户已禁用");
		}
		if(!userE.getRoleId().equals(Role.SECTION_LEADER.getId())) {
			throw new StatusException("该用户不是科组长");
		}
		User user = new User();
		user.setName(userE.getName());
		user.setSchoolId(userE.getSchoolId());
		user.setId(userE.getId());
		user.setRole(Role.getById(userE.getRoleId()));
		user.setAccessToken(FastUUID.get());
		user.buildKey();
		ActiveDataUtil.userLogin(user);
		AdminLoginVo vo=new AdminLoginVo();
		vo.setAccessToken(user.getAccessToken());
		vo.setName(user.getName());
		vo.setSessionId(user.getSessionId());
		vo.setSchoolId(user.getSchoolId());
		vo.setRole(user.getRole());
		return vo;
	}


}
